@@ -259,7 +259,7 @@ class Recorder(threading.Thread):
 
         self.fout = None
 
-        logger.info("Writing ubx data from _serial_stream [ {} ] for receiver [ {} ] to files "
+        logger.info("Writing ubx data from _serial_stream [ {} ] for receiver [ {} ] to files "
                     "in folder [ {} ], with [ {} ] periodicity".format(
                            self.serial_port, self.receiver_name, self.output_dir, self.slice.name))
 
@@ -278,7 +278,7 @@ class Recorder(threading.Thread):
             try:
                 packet_type, parsed_packet = core.parse(packet)
             except Exception as e:
-                logger.debug("Could not parse packet: {}".format(e))
+                #logger.debug("Could not parse packet: {}".format(e))
                 continue
             
             if packet_type == core.PacketType.RXM_RAWX:
@@ -287,7 +287,7 @@ class Recorder(threading.Thread):
                 epoch = weektow_to_datetime(tow, week)
                 num_packets += 1
                 incoming_epoch_suffix = self.slice.build_rinex3_epoch(epoch)
-                if num_packets % 100 == 0:
+                if num_packets % 1000 == 0:
                     logger.debug("U-blox RXM_RAWX packet found! Epoch suffix {} , num_packets = {}".format(incoming_epoch_suffix, num_packets))
 
             if not incoming_epoch_suffix:
